==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/EnvVarFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class EnvVarFluentImpl<A extends io.fabric8.kubernetes.api.model.EnvVarFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.EnvVarFluent<A>{
  public EnvVarFluentImpl() {
  }
  public EnvVarFluentImpl(io.fabric8.kubernetes.api.model.EnvVar instance) {
    this.withName(instance.getName()); 
    this.withValue(instance.getValue()); 
    this.withValueFrom(instance.getValueFrom()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String name;
  private java.lang.String value;
  private io.fabric8.kubernetes.api.model.EnvVarSourceBuilder valueFrom;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getValue() {
    return this.value;
  }
  public A withValue(java.lang.String value) {
    this.value=value; return (A) this;
  }
  public java.lang.Boolean hasValue() {
    return this.value != null;
  }
  
  /**
   * Method is deprecated. use withValue instead.
   */
  @java.lang.Deprecated
  public A withNewValue(java.lang.String arg0) {
    return (A)withValue(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildValueFrom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.EnvVarSource getValueFrom() {
    return this.valueFrom!=null?this.valueFrom.build():null;
  }
  public io.fabric8.kubernetes.api.model.EnvVarSource buildValueFrom() {
    return this.valueFrom!=null?this.valueFrom.build():null;
  }
  public A withValueFrom(io.fabric8.kubernetes.api.model.EnvVarSource valueFrom) {
    _visitables.get("valueFrom").remove(this.valueFrom);
    if (valueFrom!=null){ this.valueFrom= new io.fabric8.kubernetes.api.model.EnvVarSourceBuilder(valueFrom); _visitables.get("valueFrom").add(this.valueFrom);} return (A) this;
  }
  public java.lang.Boolean hasValueFrom() {
    return this.valueFrom != null;
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> withNewValueFrom() {
    return new io.fabric8.kubernetes.api.model.EnvVarFluentImpl.ValueFromNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> withNewValueFromLike(io.fabric8.kubernetes.api.model.EnvVarSource item) {
    return new io.fabric8.kubernetes.api.model.EnvVarFluentImpl.ValueFromNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> editValueFrom() {
    return withNewValueFromLike(getValueFrom());
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> editOrNewValueFrom() {
    return withNewValueFromLike(getValueFrom() != null ? getValueFrom(): new io.fabric8.kubernetes.api.model.EnvVarSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> editOrNewValueFromLike(io.fabric8.kubernetes.api.model.EnvVarSource item) {
    return withNewValueFromLike(getValueFrom() != null ? getValueFrom(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvVarFluentImpl that = (EnvVarFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    if (valueFrom != null ? !valueFrom.equals(that.valueFrom) :that.valueFrom != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  value,  valueFrom,  additionalProperties,  super.hashCode());
  }
  public class ValueFromNestedImpl<N> extends io.fabric8.kubernetes.api.model.EnvVarSourceFluentImpl<io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<N>> implements io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ValueFromNestedImpl(io.fabric8.kubernetes.api.model.EnvVarSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.EnvVarSourceBuilder(this, item);
    }
    ValueFromNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.EnvVarSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.EnvVarSourceBuilder builder;
    public N and() {
      return (N) EnvVarFluentImpl.this.withValueFrom(builder.build());
    }
    public N endValueFrom() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.3-sources.jar: io/fabric8/kubernetes/api/model/EnvVarFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class EnvVarFluentImpl<A extends io.fabric8.kubernetes.api.model.EnvVarFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.EnvVarFluent<A>{
  public EnvVarFluentImpl() {
  }
  public EnvVarFluentImpl(io.fabric8.kubernetes.api.model.EnvVar instance) {
    this.withName(instance.getName()); 
    this.withValue(instance.getValue()); 
    this.withValueFrom(instance.getValueFrom()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String name;
  private java.lang.String value;
  private io.fabric8.kubernetes.api.model.EnvVarSourceBuilder valueFrom;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getValue() {
    return this.value;
  }
  public A withValue(java.lang.String value) {
    this.value=value; return (A) this;
  }
  public java.lang.Boolean hasValue() {
    return this.value != null;
  }
  
  /**
   * Method is deprecated. use withValue instead.
   */
  @java.lang.Deprecated
  public A withNewValue(java.lang.String arg0) {
    return (A)withValue(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildValueFrom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.EnvVarSource getValueFrom() {
    return this.valueFrom!=null?this.valueFrom.build():null;
  }
  public io.fabric8.kubernetes.api.model.EnvVarSource buildValueFrom() {
    return this.valueFrom!=null?this.valueFrom.build():null;
  }
  public A withValueFrom(io.fabric8.kubernetes.api.model.EnvVarSource valueFrom) {
    _visitables.get("valueFrom").remove(this.valueFrom);
    if (valueFrom!=null){ this.valueFrom= new io.fabric8.kubernetes.api.model.EnvVarSourceBuilder(valueFrom); _visitables.get("valueFrom").add(this.valueFrom);} return (A) this;
  }
  public java.lang.Boolean hasValueFrom() {
    return this.valueFrom != null;
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> withNewValueFrom() {
    return new io.fabric8.kubernetes.api.model.EnvVarFluentImpl.ValueFromNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> withNewValueFromLike(io.fabric8.kubernetes.api.model.EnvVarSource item) {
    return new io.fabric8.kubernetes.api.model.EnvVarFluentImpl.ValueFromNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> editValueFrom() {
    return withNewValueFromLike(getValueFrom());
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> editOrNewValueFrom() {
    return withNewValueFromLike(getValueFrom() != null ? getValueFrom(): new io.fabric8.kubernetes.api.model.EnvVarSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<A> editOrNewValueFromLike(io.fabric8.kubernetes.api.model.EnvVarSource item) {
    return withNewValueFromLike(getValueFrom() != null ? getValueFrom(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvVarFluentImpl that = (EnvVarFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    if (valueFrom != null ? !valueFrom.equals(that.valueFrom) :that.valueFrom != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  value,  valueFrom,  additionalProperties,  super.hashCode());
  }
  public class ValueFromNestedImpl<N> extends io.fabric8.kubernetes.api.model.EnvVarSourceFluentImpl<io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<N>> implements io.fabric8.kubernetes.api.model.EnvVarFluent.ValueFromNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ValueFromNestedImpl(io.fabric8.kubernetes.api.model.EnvVarSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.EnvVarSourceBuilder(this, item);
    }
    ValueFromNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.EnvVarSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.EnvVarSourceBuilder builder;
    public N and() {
      return (N) EnvVarFluentImpl.this.withValueFrom(builder.build());
    }
    public N endValueFrom() {
      return and();
    }
    
  }
  
}
